@@ -18,7 +18,7 @@ class CWUtils:  # pylint: disable=too-few-public-methods
         :param dai_code: The dai_code (e.g. `tr-tms-obs-0008`) which will be used for setting the dimension of the metric
         :param function_name: The lambda name which will be used for setting the namespace of the metric
         """
-        allowed_metric_names = ["invocation", "error"]
+        allowed_metric_names = ["invocation", "error", "validationError"]
         if metric_name not in allowed_metric_names:
             raise DaiInputError(f"{metric_name} not in {allowed_metric_names}")
 
